==> haskell-vector-algorithms-0.9.0.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-algorithms
version:              0.9.0.3
visibility:           public
id:                   vector-algorithms-0.9.0.3-2mFvAK7OKw8EIuNfqlOQDz
key:                  vector-algorithms-0.9.0.3-2mFvAK7OKw8EIuNfqlOQDz
license:              BSD-3-Clause
copyright:
    (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
    (c) 2015 Tim Baumann

maintainer:
    Dan Doel <dan.doel@gmail.com>
    Erik de Castro Lopo <erikd@mega-nerd.com>

author:               Dan Doel
homepage:             https://github.com/erikd/vector-algorithms/
synopsis:             Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.

category:             Data
abi:                  c3f7a41b22cecab1c7532ba1c5d70d5f
exposed:              True
exposed-modules:
    Data.Vector.Algorithms Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Radix
    Data.Vector.Algorithms.Search Data.Vector.Algorithms.Tim

hidden-modules:       Data.Vector.Algorithms.Common
import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-algorithms-0.9.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-algorithms-0.9.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-algorithms
hs-libraries:         HSvector-algorithms-0.9.0.3-2mFvAK7OKw8EIuNfqlOQDz
include-dirs:
    /usr/lib/ghc-9.2.8/site-local/vector-algorithms-0.9.0.3/include

depends:
    base-4.16.4.0 bitvec-1.1.3.0-BDGKMfNWsNoHatWC5z8vFt
    bytestring-0.11.4.0 primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:
    /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock

haddock-html:         /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-algorithms-0.9.0.3-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-algorithms
version:              0.9.0.3
visibility:           public
id:                   vector-algorithms-0.9.0.3-BrcmnugOavNEKBomIpca5f
key:                  vector-algorithms-0.9.0.3-BrcmnugOavNEKBomIpca5f
license:              BSD-3-Clause
copyright:
    (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
    (c) 2015 Tim Baumann

maintainer:
    Dan Doel <dan.doel@gmail.com>
    Erik de Castro Lopo <erikd@mega-nerd.com>

author:               Dan Doel
homepage:             https://github.com/erikd/vector-algorithms/
synopsis:             Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.

category:             Data
abi:                  53c33070881e4a69cded8fe2ec4e148a
exposed:              True
exposed-modules:
    Data.Vector.Algorithms Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Radix
    Data.Vector.Algorithms.Search Data.Vector.Algorithms.Tim

hidden-modules:       Data.Vector.Algorithms.Common
import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-algorithms-0.9.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-algorithms-0.9.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-algorithms
hs-libraries:         HSvector-algorithms-0.9.0.3-BrcmnugOavNEKBomIpca5f
include-dirs:
    /usr/lib/ghc-9.2.8/site-local/vector-algorithms-0.9.0.3/include

depends:
    base-4.16.4.0 bitvec-1.1.3.0-3EIvXd8NOiGAE18tvavCaS
    bytestring-0.11.4.0 primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:
    /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock

haddock-html:         /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
